diff --git a/tests/lbm/codegen/FluctuatingMRT.cpp b/tests/lbm/codegen/FluctuatingMRT.cpp
index 46ceaea05a58e64249230b5ddbb6d338d41c1d12..342d2d4236e01cffede917dbfa537280dcd5d64c 100644
--- a/tests/lbm/codegen/FluctuatingMRT.cpp
+++ b/tests/lbm/codegen/FluctuatingMRT.cpp
@@ -74,8 +74,9 @@ int main( int argc, char ** argv )
    BlockDataID pdfFieldId = lbm::addPdfFieldToStorage( blocks, "pdf field", latticeModel, initialVelocity, real_t(1) );
    BlockDataID flagFieldId = field::addFlagFieldToStorage< FlagField_T >( blocks, "flag field" );
 
    // create and initialize boundary handling
    const FlagUID fluidFlagUID( "Fluid" );
+   geometry::setNonBoundaryCellsToDomain<FlagField_T>(*blocks, flagFieldId, fluidFlagUID);
 
    // create time loop
    SweepTimeloop timeloop( blocks->getBlockStorage(), timesteps );
@@ -84,9 +85,14 @@ int main( int argc, char ** argv )
    blockforest::communication::UniformBufferedScheme< CommunicationStencil_T > communication( blocks );
    communication.addPackInfo( make_shared< lbm::PdfFieldPackInfo< LatticeModel_T > >( pdfFieldId ) );
 
-   // add LBM sweep and communication to time loop
+   // set the RNG counter to match the time step and propagate it to the fields' copies of the lattice model
    timeloop.add() << BeforeFunction( [&](){ latticeModel.time_step_ = uint32_c(timeloop.getCurrentTimeStep()); }, "set RNG counter" )
-                  << BeforeFunction( communication, "communication" )
+                  << Sweep( [&]( IBlock * block ){
+                        auto field = block->getData< PdfField_T >( pdfFieldId );
+                        field->latticeModel().time_step_ = latticeModel.time_step_;
+                     }, "set RNG counter" );
+   // add LBM sweep and communication to time loop
+   timeloop.add() << BeforeFunction( communication, "communication" )
                   << Sweep( LatticeModel_T::Sweep( pdfFieldId ), "LB stream & collide" );
 
    // LBM stability check
@@ -74,8 +74,9 @@ int main( int argc, char ** argv )
    BlockDataID flagFieldId = field::addFlagFieldToStorage< FlagField_T >( blocks, "flag field" );
 
-   // create and initialize boundary handling
+   // create and initialize flag field
    const FlagUID fluidFlagUID( "Fluid" );